@@ -2538,7 +2538,7 @@ int ffhdr2str( fitsfile *fptr,  /* I - FITS file pointer                    */
     (*nkeys)++;
 
     *headptr = '\0';   /* terminate the header string */
-    realloc(header, (*nkeys *80) + 1);  /* minimize the allocated memory */
+    realloc(*header, (*nkeys *80) + 1);  /* minimize the allocated memory */
 
     return(*status);
 }
